# Perceptual Load Experiment

## Running Experiment on Participants


```
pip install git+https://github.com/RobBlumberg/perceptual_load
```
```
python -m perceptual_load.perceptual_load_experiment
```
